<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `taginfo`




**Global Variables**
---------------
- **WIKI_PRIMARY_LIST**
- **BASE_URL**

---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L50"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `fetch_data_from_api`

```python
fetch_data_from_api(path: str, params: dict) → dict
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L57"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_key_overview`

```python
get_key_overview(key: str) → dict
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L62"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_wiki_features_df`

```python
get_wiki_features_df(key: str) → DataFrame
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L82"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_wiki_features`

```python
get_wiki_features(key: str) → dict
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L94"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `fetch_all_data`

```python
fetch_all_data()
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L105"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `save_data`

```python
save_data(all_data: dict, save_path: str)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L109"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_data`

```python
get_data(data_filepath: str, update: bool = False) → dict
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/taginfo.py#L116"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_tag_data`

```python
get_tag_data()
```






